NAME = 'team_center_api'

# URL 定义

# 开放登录
URL_USER_LOGIN = '/open/user/login'

# 兑换token
URL_USER_TOKEN_EXCHANGE = '/open/api/user/token/exchange'

# 验证token
URL_USER_TOKEN_VERIFY = '/open/api/user/token/verify'

# 验证权限
URL_USER_PERMISSION_VERIFY = '/open/api/user/permission/verify'

# 获取所有权限
URL_USER_PERMISSIONS_ALL = '/open/api/user/permissions/all'

# 验证PIN码
URL_PIN_VERIFY = '/open/api/pin/verify'
